<?php
/*
Plugin Name: ML My Default Post Content
Version: 0.7.6
Plugin URI: No warranty! Plugin still under development.
Description: Adds a Menu to the WP backend under "tools", where you can specify default titles and default content for pages and posts.
Author: Matt L. a
Author URI: www.medienbayer.de
*/

// Add settings menu in the admin panel
add_action('admin_menu', 'mytheme_default_title_settings_menu');

function mytheme_default_title_settings_menu() {
    add_options_page(
        'Default Title and Content Settings',
        'Default Titles & Content',
        'manage_options',
        'mytheme-default-settings',
        'mytheme_default_settings_page'
    );
}

// Register settings
add_action('admin_init', 'mytheme_default_title_settings_init');

function mytheme_default_title_settings_init() {
    register_setting('mytheme_default_title_settings', 'mytheme_default_post_title');
    register_setting('mytheme_default_title_settings', 'mytheme_default_page_title');
    register_setting('mytheme_default_title_settings', 'mytheme_default_post_content');
    register_setting('mytheme_default_title_settings', 'mytheme_default_page_content');
}

// Display the settings page
function mytheme_default_settings_page() {
    ?>
    <div class="wrap">
        <h2>Default Title and Content Settings</h2>
        <form method="post" action="options.php">
            <?php settings_fields('mytheme_default_title_settings'); ?>
            <?php do_settings_sections('mytheme_default_title_settings'); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Default Post Title:</th>
                    <td><input type="text" name="mytheme_default_post_title" value="<?php echo esc_attr(get_option('mytheme_default_post_title', 'Default Post Title')); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Default Page Title:</th>
                    <td><input type="text" name="mytheme_default_page_title" value="<?php echo esc_attr(get_option('mytheme_default_page_title', 'Default Page Title')); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Default Post Content:</th>
                    <td><textarea name="mytheme_default_post_content"><?php echo esc_textarea(get_option('mytheme_default_post_content', 'Default Post Content')); ?></textarea></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Default Page Content:</th>
                    <td><textarea name="mytheme_default_page_content"><?php echo esc_textarea(get_option('mytheme_default_page_content', 'Default Page Content')); ?></textarea></td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Set default titles and content using options
add_filter('default_title', 'mytheme_default_title_content');
add_filter('default_content', 'mytheme_default_body_content');

function mytheme_default_title_content($content) {
    global $post_type;

    $default_post_title = get_option('mytheme_default_post_title', 'Default Post Title');
    $default_page_title = get_option('mytheme_default_page_title', 'Default Page Title');

    switch ($post_type) {
        case 'post':
            $content = $default_post_title;
            break;
        case 'page':
            $content = $default_page_title;
            break;
    }

    return $content;
}

function mytheme_default_body_content($content) {
    global $post_type;

    $default_post_content = get_option('mytheme_default_post_content', 'Default Post Content');
    $default_page_content = get_option('mytheme_default_page_content', 'Default Page Content');

    switch ($post_type) {
        case 'post':
            $content = $default_post_content;
            break;
        case 'page':
            $content = $default_page_content;
            break;
    }

    return $content;
}
